@@ -20,18 +20,22 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqradiobutton.h>
 #include <tqbuttongroup.h>
 #include <tqlabel.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <knuminput.h>
 #include <kpushbutton.h>
 
@@ -57,7 +61,7 @@ KEditLoanWizard::KEditLoanWizard(const MyMoneyAccount& account, TQWidget *parent
   m_effectiveDateLabel->setText(TQString("\n") + i18n(
             "Please enter the date from which on the following changes will be effective. "
             "The date entered must be later than the opening date of this account (%1), but must "
-            "not be in the future. The default will be today.").arg(KGlobal::locale()->formatDate(account.openingDate(), true)));
+            "not be in the future. The default will be today.").arg(TDEGlobal::locale()->formatDate(account.openingDate(), true)));
   m_account = account;
   try {
     TQString id = m_account.value("schedule");
@@ -75,7 +79,7 @@ KEditLoanWizard::KEditLoanWizard(const MyMoneyAccount& account, TQWidget *parent
     m_effectiveDateNoteLabel->setText(TQString("\n") + i18n(
             "Note: you will not be able to modify this account today, because the opening date \"%1\" is in the future. "
             "Please revisit this dialog when the time has come."
-            ).arg(KGlobal::locale()->formatDate(m_account.openingDate(), true)));
+            ).arg(TDEGlobal::locale()->formatDate(m_account.openingDate(), true)));
   } else {
     m_effectiveDateNoteLabel->hide();
   }
@@ -94,9 +98,9 @@ KEditLoanWizard::KEditLoanWizard(const MyMoneyAccount& account, TQWidget *parent
   setAppropriate(m_editSelectionPage, true);
 
   // setup connections
-  connect(m_effectiveChangeDateEdit, TQT_SIGNAL(dateChanged(const TQDate&)), this, TQT_SLOT(slotCheckPageFinished()));
-  connect(m_newPaymentEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotCheckPageFinished()));
-  connect(m_newInterestRateEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotCheckPageFinished()));
+  connect(m_effectiveChangeDateEdit, TQ_SIGNAL(dateChanged(const TQDate&)), this, TQ_SLOT(slotCheckPageFinished()));
+  connect(m_newPaymentEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotCheckPageFinished()));
+  connect(m_newInterestRateEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotCheckPageFinished()));
 
   // make sure, we show the correct start page
   showPage(m_editIntroPage);
@@ -133,7 +137,7 @@ void KEditLoanWizard::loadWidgets(const MyMoneyAccount& /* account */)
   m_newInterestRateEdit->setPrecision(3);
   m_interestRateLabel->setText(TQString(" ") + ir.formatMoney("", 3) + TQString("%"));
 
-  m_paymentFrequencyUnitEdit->setCurrentItem(i18n(m_schedule.occurenceToString()));
+  m_paymentFrequencyUnitEdit->setCurrentItem(i18n(m_schedule.occurenceToString().utf8()));
   updateTermWidgets(m_account.term());
 
   // the base payment (amortization and interest) is determined
@@ -172,7 +176,7 @@ void KEditLoanWizard::loadWidgets(const MyMoneyAccount& /* account */)
           m_payeeEdit->setSelectedItem(payee.id());
         } catch(MyMoneyException *e) {
           delete e;
-          qWarning("Payee for schedule has been deleted");
+          tqWarning("Payee for schedule has been deleted");
         }
       }
 
@@ -318,7 +322,7 @@ void KEditLoanWizard::next()
         setFinishEnabled(m_summaryPage, true);
 
       } else {
-        qFatal("%s,%d: This should never happen", __FILE__, __LINE__);
+        tqFatal("%s,%d: This should never happen", __FILE__, __LINE__);
       }
 
       m_lastSelection = m_selectionButtonGroup->id(m_selectionButtonGroup->selected());
@@ -434,7 +438,7 @@ void KEditLoanWizard::updateEditSummary(void)
   m_additionalFees7->setText(m_summaryAdditionalFees->text());
   m_totalPayment7->setText(m_summaryTotalPeriodicPayment->text());
   m_interestRate7->setText(m_summaryInterestRate->text());
-  m_startDateChanges->setText(KGlobal::locale()->formatDate(m_effectiveChangeDateEdit->date(), true));
+  m_startDateChanges->setText(TDEGlobal::locale()->formatDate(m_effectiveChangeDateEdit->date(), true));
 
   // calculate the number of affected transactions
   MyMoneyTransactionFilter filter(m_account.id());
