@@ -21,7 +21,7 @@
 #endif
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqpixmap.h>
 #include <tqpushbutton.h>
@@ -38,7 +38,7 @@
 #include <tqtabwidget.h>
 
 // ----------------------------------------------------------------------------
-// KDE Headers
+// TDE Headers
 
 #include <tdelocale.h>
 #include <tdeglobal.h>
@@ -358,7 +358,7 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
 
   accountNameEdit->setFocus();
 
-  if (title)
+  if (!title.isEmpty())
     setCaption(title);
 
   // load button icons
@@ -366,29 +366,29 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
   cancelButton->setGuiItem(KStdGuiItem::cancel());
   createButton->setGuiItem(KStdGuiItem::ok());
 
-  connect(cancelButton, TQT_SIGNAL(clicked()), TQT_SLOT(reject()));
-  connect(createButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(okClicked()));
-  connect(m_qlistviewParentAccounts, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
-    this, TQT_SLOT(slotSelectionChanged(TQListViewItem*)));
-  connect(m_qbuttonNew, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotNewClicked()));
-  connect(typeCombo, TQT_SIGNAL(activated(const TQString&)),
-    this, TQT_SLOT(slotAccountTypeChanged(const TQString&)));
+  connect(cancelButton, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
+  connect(createButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(okClicked()));
+  connect(m_qlistviewParentAccounts, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+    this, TQ_SLOT(slotSelectionChanged(TQListViewItem*)));
+  connect(m_qbuttonNew, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotNewClicked()));
+  connect(typeCombo, TQ_SIGNAL(activated(const TQString&)),
+    this, TQ_SLOT(slotAccountTypeChanged(const TQString&)));
 
-  connect(accountNameEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotCheckFinished()));
+  connect(accountNameEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotCheckFinished()));
 
-  connect(m_vatCategory, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotVatChanged(bool)));
-  connect(m_vatAssignment, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotVatAssignmentChanged(bool)));
-  connect(m_vatCategory, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotCheckFinished()));
-  connect(m_vatAssignment, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotCheckFinished()));
-  connect(m_vatRate, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotCheckFinished()));
-  connect(m_vatAccount, TQT_SIGNAL(stateChanged()), this, TQT_SLOT(slotCheckFinished()));
+  connect(m_vatCategory, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotVatChanged(bool)));
+  connect(m_vatAssignment, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotVatAssignmentChanged(bool)));
+  connect(m_vatCategory, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotCheckFinished()));
+  connect(m_vatAssignment, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotCheckFinished()));
+  connect(m_vatRate, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotCheckFinished()));
+  connect(m_vatAccount, TQ_SIGNAL(stateChanged()), this, TQ_SLOT(slotCheckFinished()));
 
-  connect(m_minBalanceEarlyEdit, TQT_SIGNAL(valueChanged(const TQString&)), this, TQT_SLOT(slotAdjustMinBalanceAbsoluteEdit(const TQString&)));
-  connect(m_minBalanceAbsoluteEdit, TQT_SIGNAL(valueChanged(const TQString&)), this, TQT_SLOT(slotAdjustMinBalanceEarlyEdit(const TQString&)));
-  connect(m_maxCreditEarlyEdit, TQT_SIGNAL(valueChanged(const TQString&)), this, TQT_SLOT(slotAdjustMaxCreditAbsoluteEdit(const TQString&)));
-  connect(m_maxCreditAbsoluteEdit, TQT_SIGNAL(valueChanged(const TQString&)), this, TQT_SLOT(slotAdjustMaxCreditEarlyEdit(const TQString&)));
+  connect(m_minBalanceEarlyEdit, TQ_SIGNAL(valueChanged(const TQString&)), this, TQ_SLOT(slotAdjustMinBalanceAbsoluteEdit(const TQString&)));
+  connect(m_minBalanceAbsoluteEdit, TQ_SIGNAL(valueChanged(const TQString&)), this, TQ_SLOT(slotAdjustMinBalanceEarlyEdit(const TQString&)));
+  connect(m_maxCreditEarlyEdit, TQ_SIGNAL(valueChanged(const TQString&)), this, TQ_SLOT(slotAdjustMaxCreditAbsoluteEdit(const TQString&)));
+  connect(m_maxCreditAbsoluteEdit, TQ_SIGNAL(valueChanged(const TQString&)), this, TQ_SLOT(slotAdjustMaxCreditEarlyEdit(const TQString&)));
 
-  connect(m_qcomboboxInstitutions, TQT_SIGNAL(activated(const TQString&)), this, TQT_SLOT(slotLoadInstitutions(const TQString&)));
+  connect(m_qcomboboxInstitutions, TQ_SIGNAL(activated(const TQString&)), this, TQ_SLOT(slotLoadInstitutions(const TQString&)));
 
   m_vatCategory->setChecked(false);
   m_vatAssignment->setChecked(false);
@@ -435,14 +435,14 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
   slotVatAssignmentChanged(m_vatAssignment->isChecked());
   slotCheckFinished();
 
-  kMandatoryFieldGroup* requiredFields = new kMandatoryFieldGroup (TQT_TQOBJECT(this));
+  kMandatoryFieldGroup* requiredFields = new kMandatoryFieldGroup (this);
   requiredFields->setOkButton(createButton); // button to be enabled when all fields present
   requiredFields->add(accountNameEdit);
 
   // using a timeout is the only way, I got the 'ensureItemVisible'
   // working when creating the dialog. I assume, this
   // has something to do with the delayed update of the display somehow.
-  TQTimer::singleShot(50, this, TQT_SLOT(timerDone()));
+  TQTimer::singleShot(50, this, TQ_SLOT(timerDone()));
 }
 
 void KNewAccountDlg::timerDone(void)
