@@ -15,8 +15,12 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqlabel.h>
 #include <tqapplication.h>
@@ -26,7 +30,7 @@
 #include <tqtooltip.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdeglobal.h>
 #include <ktextedit.h>
@@ -70,7 +74,7 @@ TransactionEditor::TransactionEditor(TransactionEditorContainer* regForm, KMyMon
   m_openEditSplits(false)
 {
   m_item->startEditMode();
-  connect(MyMoneyFile::instance(), TQT_SIGNAL(dataChanged()), this, TQT_SLOT(slotUpdateAccount()));
+  connect(MyMoneyFile::instance(), TQ_SIGNAL(dataChanged()), this, TQ_SLOT(slotUpdateAccount()));
 }
 
 TransactionEditor::~TransactionEditor()
@@ -149,7 +153,7 @@ void TransactionEditor::slotReloadEditWidgets(void)
 bool TransactionEditor::eventFilter(TQObject* o, TQEvent* e)
 {
   bool rc = false;
-  if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(haveWidget("number"))) {
+  if(o == haveWidget("number")) {
     if(e->type() == TQEvent::MouseButtonDblClick) {
       emit assignNumber();
       rc = true;
@@ -176,7 +180,7 @@ bool TransactionEditor::eventFilter(TQObject* o, TQEvent* e)
           // we treat the return/enter key as such.
           if(KMyMoneyGlobalSettings::enterMovesBetweenFields()) {
             for(it_w = m_finalEditWidgets.begin(); !isFinal && it_w != m_finalEditWidgets.end(); ++it_w) {
-              if(TQT_BASE_OBJECT_CONST(*it_w) == TQT_BASE_OBJECT(o)) {
+              if(*it_w == o) {
                 if(dynamic_cast<const kMyMoneyEdit*>(*it_w)) {
                   isFinal = !(dynamic_cast<const kMyMoneyEdit*>(*it_w)->value().isZero());
                 } else
@@ -199,14 +203,14 @@ bool TransactionEditor::eventFilter(TQObject* o, TQEvent* e)
               TQApplication::sendEvent( o, &evt );
 
           } else {
-            TQTimer::singleShot(0, this, TQT_SIGNAL(returnPressed()));
+            TQTimer::singleShot(0, this, TQ_SIGNAL(returnPressed()));
           }
           // don't process any further
           rc = true;
           break;
 
         case TQt::Key_Escape:
-          TQTimer::singleShot(0, this, TQT_SIGNAL(escapePressed()));
+          TQTimer::singleShot(0, this, TQ_SIGNAL(escapePressed()));
           break;
       }
     }
@@ -281,7 +285,7 @@ int TransactionEditor::slotEditSplits(void)
           *m_transactionPtr = k;
         }
       } catch(MyMoneyException *e) {
-        tqDebug("Unable to update commodity to second splits currency in %s: '%s'", m_transaction.id().data(), e->what().data());
+        tqDebug(TQString("Unable to update commodity to second splits currency in %1: '%2'").arg(m_transaction.id()).arg(e->what()));
         delete e;
       }
 
@@ -357,7 +361,7 @@ bool TransactionEditor::fixTransactionCommodity(const MyMoneyAccount& account)
             (*it_t).transaction().modifySplit(splitB);
 
           } catch(MyMoneyException *e) {
-            tqDebug("Unable to update commodity to second splits currency in %s: '%s'", (*it_t).transaction().id().data(), e->what().data());
+            tqDebug(TQString("Unable to update commodity to second splits currency in %1: '%2'").arg((*it_t).transaction().id()).arg(e->what()));
             delete e;
           }
           break;
@@ -394,7 +398,7 @@ bool TransactionEditor::fixTransactionCommodity(const MyMoneyAccount& account)
             (*it_t).transaction().modifySplit(splitB);
 
           } catch(MyMoneyException *e) {
-            tqDebug("Unable to update commodity to second splits currency in %s: '%s'", (*it_t).transaction().id().data(), e->what().data());
+            tqDebug(TQString("Unable to update commodity to second splits currency in %1: '%2'").arg((*it_t).transaction().id()).arg(e->what()));
             delete e;
           }
           break;
@@ -440,7 +444,7 @@ bool TransactionEditor::fixTransactionCommodity(const MyMoneyAccount& account)
               }
             }
           } catch(MyMoneyException *e) {
-            tqDebug("Unable to update commodity of split currency in %s: '%s'", (*it_t).transaction().id().data(), e->what().data());
+            tqDebug(TQString("Unable to update commodity of split currency in %1: '%2'").arg((*it_t).transaction().id()).arg(e->what()));
             delete e;
           }
           break;
@@ -474,7 +478,7 @@ bool TransactionEditor::canAssignNumber(void) const
 
 void TransactionEditor::setupCategoryWidget(KMyMoneyCategory* category, const TQValueList<MyMoneySplit>& splits, TQString& categoryId, const char* splitEditSlot, bool /* allowObjectCreation */)
 {
-  disconnect(category, TQT_SIGNAL(focusIn()), this, splitEditSlot);
+  disconnect(category, TQ_SIGNAL(focusIn()), this, splitEditSlot);
 #if 0
   // FIXME must deal with the logic that suppressObjectCreation is
   // automatically turned off when the createItem() signal is connected
@@ -502,7 +506,7 @@ void TransactionEditor::setupCategoryWidget(KMyMoneyCategory* category, const TQ
     default:
       categoryId = TQString();
       category->setSplitTransaction();
-      connect(category, TQT_SIGNAL(focusIn()), this, splitEditSlot);
+      connect(category, TQ_SIGNAL(focusIn()), this, splitEditSlot);
 #if 0
   // FIXME must deal with the logic that suppressObjectCreation is
   // automatically turned off when the createItem() signal is connected
@@ -523,7 +527,7 @@ bool TransactionEditor::enterTransactions(TQString& newId, bool askForSchedule,
   TQApplication::eventLoop()->processEvents(TQEventLoop::ExcludeUserInput, 10);
 
   // we don't need to update our widgets anymore, so we just disconnect the signal
-  disconnect(file, TQT_SIGNAL(dataChanged()), this, TQT_SLOT(slotReloadEditWidgets()));
+  disconnect(file, TQ_SIGNAL(dataChanged()), this, TQ_SLOT(slotReloadEditWidgets()));
 
   KMyMoneyRegister::SelectedTransactions::iterator it_t;
   MyMoneyTransaction t;
@@ -707,7 +711,7 @@ bool TransactionEditor::enterTransactions(TQString& newId, bool askForSchedule,
         }
       }
     } catch(MyMoneyException * e) {
-      tqDebug("Unable to store transaction within engine: %s", e->what().latin1());
+      tqDebug(TQString("Unable to store transaction within engine: %1").arg(e->what()));
       delete e;
       newTransactionCreated = false;
     }
@@ -762,25 +766,25 @@ void StdTransactionEditor::createEditWidgets(void)
   KMyMoneyCategory* account = new KMyMoneyCategory;
   account->setHint(i18n("Account"));
   m_editWidgets["account"] = account;
-  connect(account, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
-  connect(account, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotUpdateAccount(const TQString&)));
+  connect(account, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
+  connect(account, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotUpdateAccount(const TQString&)));
 
   KMyMoneyPayeeCombo* payee = new KMyMoneyPayeeCombo;
   payee->setHint(i18n("Payer/Receiver"));
   m_editWidgets["payee"] = payee;
-  connect(payee, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
-  connect(payee, TQT_SIGNAL(createItem(const TQString&, TQString&)), this, TQT_SIGNAL(createPayee(const TQString&, TQString&)));
-  connect(payee, TQT_SIGNAL(objectCreation(bool)), this, TQT_SIGNAL(objectCreation(bool)));
-  connect(payee, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotUpdatePayee(const TQString&)));
+  connect(payee, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
+  connect(payee, TQ_SIGNAL(createItem(const TQString&, TQString&)), this, TQ_SIGNAL(createPayee(const TQString&, TQString&)));
+  connect(payee, TQ_SIGNAL(objectCreation(bool)), this, TQ_SIGNAL(objectCreation(bool)));
+  connect(payee, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotUpdatePayee(const TQString&)));
 
   KMyMoneyCategory* category = new KMyMoneyCategory(0, 0, true);
   category->setHint(i18n("Category/Account"));
   m_editWidgets["category"] = category;
-  connect(category, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotUpdateCategory(const TQString&)));
-  connect(category, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
-  connect(category, TQT_SIGNAL(createItem(const TQString&, TQString&)), this, TQT_SLOT(slotCreateCategory(const TQString&, TQString&)));
-  connect(category, TQT_SIGNAL(objectCreation(bool)), this, TQT_SIGNAL(objectCreation(bool)));
-  connect(category->splitButton(), TQT_SIGNAL(clicked()), this, TQT_SLOT(slotEditSplits()));
+  connect(category, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotUpdateCategory(const TQString&)));
+  connect(category, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
+  connect(category, TQ_SIGNAL(createItem(const TQString&, TQString&)), this, TQ_SLOT(slotCreateCategory(const TQString&, TQString&)));
+  connect(category, TQ_SIGNAL(objectCreation(bool)), this, TQ_SIGNAL(objectCreation(bool)));
+  connect(category->splitButton(), TQ_SIGNAL(clicked()), this, TQ_SLOT(slotEditSplits()));
   category->splitButton()->setDisabled(true);
 
   KTextEdit* memo = new KTextEdit;
@@ -812,39 +816,39 @@ void StdTransactionEditor::createEditWidgets(void)
     kMyMoneyLineEdit* number = new kMyMoneyLineEdit;
     number->setHint(i18n("Number"));
     m_editWidgets["number"] = number;
-    connect(number, TQT_SIGNAL(lineChanged(const TQString&)), this, TQT_SLOT(slotNumberChanged(const TQString&)));
+    connect(number, TQ_SIGNAL(lineChanged(const TQString&)), this, TQ_SLOT(slotNumberChanged(const TQString&)));
     // number->installEventFilter(this);
   }
 
   m_editWidgets["postdate"] = new kMyMoneyDateInput;
-  connect(m_editWidgets["postdate"], TQT_SIGNAL(dateChanged(const TQDate&)), this, TQT_SLOT(slotUpdateButtonState()));
+  connect(m_editWidgets["postdate"], TQ_SIGNAL(dateChanged(const TQDate&)), this, TQ_SLOT(slotUpdateButtonState()));
 
   kMyMoneyEdit* value = new kMyMoneyEdit;
   m_editWidgets["amount"] = value;
   value->setResetButtonVisible(false);
-  connect(value, TQT_SIGNAL(valueChanged(const TQString&)), this, TQT_SLOT(slotUpdateAmount(const TQString&)));
-  connect(value, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
+  connect(value, TQ_SIGNAL(valueChanged(const TQString&)), this, TQ_SLOT(slotUpdateAmount(const TQString&)));
+  connect(value, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
 
   value = new kMyMoneyEdit;
   m_editWidgets["payment"] = value;
   value->setResetButtonVisible(false);
-  connect(value, TQT_SIGNAL(valueChanged(const TQString&)), this, TQT_SLOT(slotUpdatePayment(const TQString&)));
-  connect(value, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
+  connect(value, TQ_SIGNAL(valueChanged(const TQString&)), this, TQ_SLOT(slotUpdatePayment(const TQString&)));
+  connect(value, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
 
   value = new kMyMoneyEdit;
   m_editWidgets["deposit"] = value;
   value->setResetButtonVisible(false);
-  connect(value, TQT_SIGNAL(valueChanged(const TQString&)), this, TQT_SLOT(slotUpdateDeposit(const TQString&)));
-  connect(value, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
+  connect(value, TQ_SIGNAL(valueChanged(const TQString&)), this, TQ_SLOT(slotUpdateDeposit(const TQString&)));
+  connect(value, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
 
   KMyMoneyCashFlowCombo* cashflow = new KMyMoneyCashFlowCombo(0, 0, m_account.accountGroup());
   m_editWidgets["cashflow"] = cashflow;
-  connect(cashflow, TQT_SIGNAL(directionSelected(KMyMoneyRegister::CashFlowDirection)), this, TQT_SLOT(slotUpdateCashFlow(KMyMoneyRegister::CashFlowDirection)));
-  connect(cashflow, TQT_SIGNAL(directionSelected(KMyMoneyRegister::CashFlowDirection)), this, TQT_SLOT(slotUpdateButtonState()));
+  connect(cashflow, TQ_SIGNAL(directionSelected(KMyMoneyRegister::CashFlowDirection)), this, TQ_SLOT(slotUpdateCashFlow(KMyMoneyRegister::CashFlowDirection)));
+  connect(cashflow, TQ_SIGNAL(directionSelected(KMyMoneyRegister::CashFlowDirection)), this, TQ_SLOT(slotUpdateButtonState()));
 
   KMyMoneyReconcileCombo* reconcile = new KMyMoneyReconcileCombo;
   m_editWidgets["status"] = reconcile;
-  connect(reconcile, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
+  connect(reconcile, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
 
   KMyMoneyRegister::TQWidgetContainer::iterator it_w;
   for(it_w = m_editWidgets.begin(); it_w != m_editWidgets.end(); ++it_w) {
@@ -868,7 +872,7 @@ void StdTransactionEditor::createEditWidgets(void)
     KMyMoneyTransactionForm::TabBar* tabbar = new KMyMoneyTransactionForm::TabBar;
     m_editWidgets["tabbar"] = tabbar;
     tabbar->copyTabs(form->tabBar());
-    connect(tabbar, TQT_SIGNAL(tabSelected(int)), this, TQT_SLOT(slotUpdateAction(int)));
+    connect(tabbar, TQ_SIGNAL(tabSelected(int)), this, TQ_SLOT(slotUpdateAction(int)));
   }
 
   label = new TQLabel(i18n("Date"), 0);
@@ -884,7 +888,7 @@ void StdTransactionEditor::createEditWidgets(void)
 
 void StdTransactionEditor::setupCategoryWidget(TQString& categoryId)
 {
-  TransactionEditor::setupCategoryWidget(dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]), m_splits, categoryId, TQT_SLOT(slotEditSplits()));
+  TransactionEditor::setupCategoryWidget(dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]), m_splits, categoryId, TQ_SLOT(slotEditSplits()));
 
   if(m_splits.count() == 1)
     m_shares = m_splits[0].shares();
@@ -929,7 +933,7 @@ void StdTransactionEditor::loadEditWidgets(KMyMoneyRegister::Action action)
 
   // load the category widget
   KMyMoneyCategory* category = dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]);
-  disconnect(category, TQT_SIGNAL(focusIn()), this, TQT_SLOT(slotEditSplits()));
+  disconnect(category, TQ_SIGNAL(focusIn()), this, TQ_SLOT(slotEditSplits()));
 
   // check if the current transaction has a reference to an equity account
   bool haveEquityAccount = false;
@@ -1443,7 +1447,7 @@ void StdTransactionEditor::slotUpdateCashFlow(KMyMoneyRegister::CashFlowDirectio
 void StdTransactionEditor::slotUpdateCategory(const TQString& id)
 {
   TQLabel *categoryLabel = dynamic_cast<TQLabel*>(haveWidget("category-label"));
-  // tqDebug("Update category to %s", id.data());
+  // tqDebug(TQString("Update category to %1").arg(id));
 
   if(categoryLabel) {
     TabBar* tabbar = dynamic_cast<TabBar*>(haveWidget("tabbar"));
@@ -1522,7 +1526,7 @@ void StdTransactionEditor::slotUpdateDeposit(const TQString& txt)
 
 void StdTransactionEditor::slotUpdateAmount(const TQString& txt)
 {
-  // tqDebug("Update amount to %s", txt.data());
+  // tqDebug(TQString("Update amount to %1").arg(txt));
   MyMoneyMoney val(txt);
   updateAmount(val);
   updateVAT(true);
@@ -1657,7 +1661,7 @@ bool StdTransactionEditor::addVatSplit(MyMoneyTransaction& tr, const MyMoneyMone
 
       tax.setAccountId(vatAcc.id());
 
-      // tqDebug("vat amount is '%s'", category.value("VatAmount").latin1());
+      // tqDebug(TQString("vat amount is '%1'").arg(category.value("VatAmount")));
       if(category.value("VatAmount").lower() != TQString("net")) {
         // split value is the gross value
         gv = amount;
@@ -1740,7 +1744,6 @@ MyMoneyMoney StdTransactionEditor::removeVatSplit(void)
 bool StdTransactionEditor::isComplete(TQString& reason) const
 {
   reason = TQString();
-  // reason.clear();  // for TQt4
 
   TQMap<TQString, TQWidget*>::const_iterator it_w;
   kMyMoneyDateInput* postDate = dynamic_cast<kMyMoneyDateInput*>(m_editWidgets["postdate"]);
@@ -1877,8 +1880,8 @@ int StdTransactionEditor::slotEditSplits(void)
                                                           0,
                                                           m_priceInfo,
                                                           m_regForm);
-      connect(dlg, TQT_SIGNAL(objectCreation(bool)), this, TQT_SIGNAL(objectCreation(bool)));
-      connect(dlg, TQT_SIGNAL(createCategory(MyMoneyAccount&, const MyMoneyAccount&)), this, TQT_SIGNAL(createCategory(MyMoneyAccount&, const MyMoneyAccount&)));
+      connect(dlg, TQ_SIGNAL(objectCreation(bool)), this, TQ_SIGNAL(objectCreation(bool)));
+      connect(dlg, TQ_SIGNAL(createCategory(MyMoneyAccount&, const MyMoneyAccount&)), this, TQ_SIGNAL(createCategory(MyMoneyAccount&, const MyMoneyAccount&)));
 
       if((rc = dlg->exec()) == TQDialog::Accepted) {
         m_transaction = dlg->transaction();
