@@ -20,6 +20,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "mymoneyexception.h"
 
 MyMoneyException::MyMoneyException(const TQString& msg, const TQString& file, const unsigned long line)
