@@ -14,6 +14,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // make sure, that this is defined before we even include any other header file
 #ifndef __STDC_LIMIT_MACROS
   #define __STDC_LIMIT_MACROS         // force definition of min and max values
@@ -26,9 +30,9 @@
 
 // make sure, we have the correct suffix
 #if SIZEOF_LONG == 8
-#define LLCONST(a) a ## L
+#define LLCONST(a) (signed64)a ## L
 #else
-#define LLCONST(a) a ## LL
+#define LLCONST(a) (signed64)a ## LL
 #endif
 
 MyMoneyMoneyTest::MyMoneyMoneyTest()
