@@ -263,13 +263,13 @@ void MyMoneyScheduleTest::testOverdue()
 		"  </TRANSACTION>\n"
 		" </SCHEDULED_TX>\n"
 		"</SCHEDULE-CONTAINER>\n");
-	TQString ref_overdue = ref.arg(startDate.toString(Qt::ISODate))
-	 .arg(lastPaymentDate.toString(Qt::ISODate))
-	 .arg(lastPaymentDate.toString(Qt::ISODate));
+	TQString ref_overdue = ref.arg(startDate.toString(TQt::ISODate))
+	 .arg(lastPaymentDate.toString(TQt::ISODate))
+	 .arg(lastPaymentDate.toString(TQt::ISODate));
 
-	TQString ref_intime = ref.arg(startDate.addDays(1).toString(Qt::ISODate))
-	 .arg(lastPaymentDate.addDays(1).toString(Qt::ISODate))
-	 .arg(lastPaymentDate.addDays(1).toString(Qt::ISODate));
+	TQString ref_intime = ref.arg(startDate.addDays(1).toString(TQt::ISODate))
+	 .arg(lastPaymentDate.addDays(1).toString(TQt::ISODate))
+	 .arg(lastPaymentDate.addDays(1).toString(TQt::ISODate));
 
 	TQDomDocument doc;
 	TQDomElement node;
@@ -1075,9 +1075,9 @@ void MyMoneyScheduleTest::testWriteXML() {
 		"  </TRANSACTION>\n"
 		" </SCHEDULED_TX>\n"
 		"</SCHEDULE-CONTAINER>\n"
-	).arg(TQDate::currentDate().toString(Qt::ISODate))
-	 .arg(TQDate::currentDate().toString(Qt::ISODate))
-	 .arg(TQDate::currentDate().toString(Qt::ISODate));
+	).arg(TQDate::currentDate().toString(TQt::ISODate))
+	 .arg(TQDate::currentDate().toString(TQt::ISODate))
+	 .arg(TQDate::currentDate().toString(TQt::ISODate));
 
 	CPPUNIT_ASSERT(doc.toString() == ref);
 }
@@ -1103,9 +1103,9 @@ void MyMoneyScheduleTest::testReadXML() {
 		"  </TRANSACTION>\n"
 		" </SCHEDULED_TX>\n"
 		"</SCHEDULE-CONTAINER>\n"
-	).arg(TQDate::currentDate().toString(Qt::ISODate))
-	 .arg(TQDate::currentDate().toString(Qt::ISODate))
-	 .arg(TQDate::currentDate().toString(Qt::ISODate));
+	).arg(TQDate::currentDate().toString(TQt::ISODate))
+	 .arg(TQDate::currentDate().toString(TQt::ISODate))
+	 .arg(TQDate::currentDate().toString(TQt::ISODate));
 
 	// diff to ref_ok1 is that we now have an empty entrydate
 	// in the transaction parameters
@@ -1127,9 +1127,9 @@ void MyMoneyScheduleTest::testReadXML() {
 		"  </TRANSACTION>\n"
 		" </SCHEDULED_TX>\n"
 		"</SCHEDULE-CONTAINER>\n"
-	).arg(TQDate::currentDate().toString(Qt::ISODate))
-	 .arg(TQDate::currentDate().toString(Qt::ISODate))
-	 .arg(TQDate::currentDate().toString(Qt::ISODate));
+	).arg(TQDate::currentDate().toString(TQt::ISODate))
+	 .arg(TQDate::currentDate().toString(TQt::ISODate))
+	 .arg(TQDate::currentDate().toString(TQt::ISODate));
 
 	TQString ref_false = TQString(
 		"<!DOCTYPE TEST>\n"
@@ -1149,9 +1149,9 @@ void MyMoneyScheduleTest::testReadXML() {
 		"  </TRANSACTION>\n"
 		" </SCHEDULED_TX>\n"
 		"</SCHEDULE-CONTAINER>\n"
-	).arg(TQDate::currentDate().toString(Qt::ISODate))
-	 .arg(TQDate::currentDate().toString(Qt::ISODate))
-	 .arg(TQDate::currentDate().toString(Qt::ISODate));
+	).arg(TQDate::currentDate().toString(TQt::ISODate))
+	 .arg(TQDate::currentDate().toString(TQt::ISODate))
+	 .arg(TQDate::currentDate().toString(TQt::ISODate));
 
 	TQDomDocument doc;
 	TQDomElement node;
@@ -1241,9 +1241,9 @@ void MyMoneyScheduleTest::testHasReferenceTo()
 		"  </TRANSACTION>\n"
 		" </SCHEDULED_TX>\n"
 		"</SCHEDULE-CONTAINER>\n"
-	).arg(TQDate::currentDate().toString(Qt::ISODate))
-	 .arg(TQDate::currentDate().toString(Qt::ISODate))
-	 .arg(TQDate::currentDate().toString(Qt::ISODate));
+	).arg(TQDate::currentDate().toString(TQt::ISODate))
+	 .arg(TQDate::currentDate().toString(TQt::ISODate))
+	 .arg(TQDate::currentDate().toString(TQt::ISODate));
 
 	TQDomDocument doc;
 	TQDomElement node;
@@ -1892,9 +1892,9 @@ void MyMoneyScheduleTest::testPaidEarlyOneTime()
                      "  </TRANSACTION>\n"
                      " </SCHEDULED_TX>\n"
                      "</SCHEDULE-CONTAINER>\n"
-                   ).arg(paymentInFuture.toString(Qt::ISODate))
-                   .arg(paymentInFuture.toString(Qt::ISODate))
-                   .arg(paymentInFuture.toString(Qt::ISODate));
+                   ).arg(paymentInFuture.toString(TQt::ISODate))
+                   .arg(paymentInFuture.toString(TQt::ISODate))
+                   .arg(paymentInFuture.toString(TQt::ISODate));
 
   TQDomDocument doc;
   TQDomElement node;
