@@ -19,10 +19,10 @@
 #define KMMIMPORTINTERFACE_H
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdefile.h>
 #include <kurl.h>
@@ -40,7 +40,7 @@ namespace KMyMoneyPlugin {
   * ViewInterface.
   */
 class KMMImportInterface : public ImportInterface {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
