@@ -15,6 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <tqvaluelist.h>
 #include <tqvaluevector.h>
 #include <tqdom.h>
@@ -117,7 +121,7 @@ void PivotTableTest::testNetWorthSingle()
   }
   catch(MyMoneyException *e)
   {
-    CPPUNIT_FAIL(e->what());
+    CPPUNIT_FAIL(e->what().local8Bit().data());
     delete e;
   }
 }
@@ -934,7 +938,7 @@ void PivotTableTest::testInvestment(void)
   }
   catch(MyMoneyException *e)
   {
-    CPPUNIT_FAIL(e->what());
+    CPPUNIT_FAIL(e->what().local8Bit().data());
     delete e;
   }
 }
