@@ -15,8 +15,12 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqtabwidget.h>
 #include <tqlabel.h>
@@ -28,7 +32,7 @@
 #include <tqapplication.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdeglobal.h>
 #include <tdelocale.h>
@@ -79,20 +83,20 @@ KBudgetValues::KBudgetValues(TQWidget* parent, const char* name) :
   m_monthlyButton->setChecked(true);
   slotChangePeriod(m_periodGroup->id(m_monthlyButton));
 
-  // connect(m_budgetLevel, TQT_SIGNAL(currentChanged(TQWidget*)), this, TQT_SIGNAL(valuesChanged()));
-  connect(m_amountMonthly, TQT_SIGNAL(valueChanged(const TQString&)), this, TQT_SLOT(slotNeedUpdate()));
-  connect(m_amountYearly, TQT_SIGNAL(valueChanged(const TQString&)), this, TQT_SLOT(slotNeedUpdate()));
+  // connect(m_budgetLevel, TQ_SIGNAL(currentChanged(TQWidget*)), this, TQ_SIGNAL(valuesChanged()));
+  connect(m_amountMonthly, TQ_SIGNAL(valueChanged(const TQString&)), this, TQ_SLOT(slotNeedUpdate()));
+  connect(m_amountYearly, TQ_SIGNAL(valueChanged(const TQString&)), this, TQ_SLOT(slotNeedUpdate()));
   m_amountMonthly->installEventFilter(this);
   m_amountYearly->installEventFilter(this);
 
   for(int i=0; i < 12; ++i) {
-    connect(m_field[i], TQT_SIGNAL(valueChanged(const TQString&)), this, TQT_SLOT(slotNeedUpdate()));
+    connect(m_field[i], TQ_SIGNAL(valueChanged(const TQString&)), this, TQ_SLOT(slotNeedUpdate()));
     m_field[i]->installEventFilter(this);
   }
 
-  connect(m_clearButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotClearAllValues()));
-  connect(m_periodGroup, TQT_SIGNAL(clicked(int)), this, TQT_SLOT(slotChangePeriod(int)));
-  connect(this, TQT_SIGNAL(valuesChanged()), this, TQT_SLOT(slotUpdateClearButton()));
+  connect(m_clearButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotClearAllValues()));
+  connect(m_periodGroup, TQ_SIGNAL(clicked(int)), this, TQ_SLOT(slotChangePeriod(int)));
+  connect(this, TQ_SIGNAL(valuesChanged()), this, TQ_SLOT(slotUpdateClearButton()));
 
   KGuiItem clearItem(KStdGuiItem::clear());
 
@@ -238,7 +242,7 @@ void KBudgetValues::slotChangePeriod(int id)
 void KBudgetValues::slotNeedUpdate(void)
 {
   if(!signalsBlocked())
-    TQTimer::singleShot(0, this, TQT_SIGNAL(valuesChanged()));
+    TQTimer::singleShot(0, this, TQ_SIGNAL(valuesChanged()));
 }
 
 void KBudgetValues::enableMonths(bool enabled)
